@@ -3,7 +3,12 @@ from fastapi.middleware.cors import CORSMiddleware
 
 from simaple.app.interface.container import WebContainer, WebSetting
 from simaple.app.interface.handler import add_exception_handlers
-from simaple.app.interface.routers import snapshot, statistics, workspace
+from simaple.app.interface.routers import (
+    component_spec,
+    snapshot,
+    statistics,
+    workspace,
+)
 from simaple.app.interface.routers.component_spec import component_spec_router
 from simaple.app.interface.routers.snapshot import snapshot_router
 from simaple.app.interface.routers.statistics import statistics_router
@@ -16,7 +21,7 @@ class SimapleWeb(fastapi.FastAPI):
 
         container = WebContainer()
         container.config.from_pydantic(WebSetting())
-        container.wire(packages=[statistics, workspace, snapshot])
+        container.wire(packages=[statistics, workspace, snapshot, component_spec])
 
         self.container: WebContainer = container
 
