@@ -4,7 +4,7 @@ from typing import List, Union
 
 from pydantic import BaseModel, Extra, Field
 
-from simaple.core import ActionStat, LevelStat, Stat
+from simaple.core import ActionStat, ExtendedStat, LevelStat, Stat
 
 
 class PotentialTier(enum.IntEnum):
@@ -17,6 +17,13 @@ class PotentialTier(enum.IntEnum):
 
 
 class PotentialInterface(BaseModel, metaclass=ABCMeta):
+    def get_extended_stat(self) -> ExtendedStat:
+        return ExtendedStat(
+            stat=self.get_stat(),
+            action_stat=self.get_action_stat(),
+            level_stat=self.get_level_stat(),
+        )
+
     @abstractmethod
     def get_stat(self, level: int = 0) -> Stat:
         ...
@@ -25,6 +32,10 @@ class PotentialInterface(BaseModel, metaclass=ABCMeta):
     def get_action_stat(self) -> ActionStat:
         ...
 
+    @abstractmethod
+    def get_level_stat(self) -> LevelStat:
+        ...
+
 
 class AbstractPotential(PotentialInterface):
     class Config:
@@ -50,6 +61,14 @@ class AbstractPotential(PotentialInterface):
 
         return action_stat
 
+    def get_level_stat(self) -> LevelStat:
+        level_stat = LevelStat()
+        for option in self.options:
+            if isinstance(option, LevelStat):
+                level_stat += option
+
+        return level_stat
+
 
 class Potential(AbstractPotential):
     ...
